==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ymsiptopology/rev20140101/ymsiptopology/node/terminationpoints/terminationpoint/DefaultAugmentedTopoTerminationPoint.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ymsiptopology.rev20140101.ymsiptopology.node.terminationpoints.terminationpoint;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedTopoTerminationPoint.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedTopoTerminationPoint extends InnerModelObject implements AugmentedTopoTerminationPoint {
    protected String ipAddress;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String ipAddress() {
        return ipAddress;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void ipAddress(String ipAddress) {
        valueLeafFlags.set(LeafIdentifier.IPADDRESS.getLeafIndex());
        this.ipAddress = ipAddress;
    }

    @Override
    public int hashCode() {
        return Objects.hash(ipAddress, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedTopoTerminationPoint) {
            DefaultAugmentedTopoTerminationPoint other = (DefaultAugmentedTopoTerminationPoint) obj;
            return
                Objects.equals(ipAddress, other.ipAddress) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("ipAddress=" + ipAddress)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedTopoTerminationPoint.
     */
    public DefaultAugmentedTopoTerminationPoint() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ymsiptopology/rev20140101/ymsiptopology/node/terminationpoints/terminationpoint/DefaultAugmentedTopoTerminationPoint.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ymsiptopology.rev20140101.ymsiptopology.node.terminationpoints.terminationpoint;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedTopoTerminationPoint.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedTopoTerminationPoint extends InnerModelObject implements AugmentedTopoTerminationPoint {
    protected String ipAddress;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String ipAddress() {
        return ipAddress;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void ipAddress(String ipAddress) {
        valueLeafFlags.set(LeafIdentifier.IPADDRESS.getLeafIndex());
        this.ipAddress = ipAddress;
    }

    @Override
    public int hashCode() {
        return Objects.hash(ipAddress, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedTopoTerminationPoint) {
            DefaultAugmentedTopoTerminationPoint other = (DefaultAugmentedTopoTerminationPoint) obj;
            return
                Objects.deepEquals(ipAddress, other.ipAddress) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("ipAddress=" + ipAddress)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedTopoTerminationPoint.
     */
    public DefaultAugmentedTopoTerminationPoint() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
